# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateLdapAuthConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_id': 'str',
        'bind_dn': 'str',
        'bind_dn_password': 'str',
        'group_attr': 'str',
        'group_dn': 'str',
        'group_filter': 'str',
        'json': 'bool',
        'ldap_ca_cert': 'str',
        'ldap_enable': 'str',
        'ldap_url': 'str',
        'ldap_anonymous_search': 'bool',
        'signing_key_data': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_attribute': 'str',
        'user_dn': 'str'
    }

    attribute_map = {
        'access_id': 'access-id',
        'bind_dn': 'bind-dn',
        'bind_dn_password': 'bind-dn-password',
        'group_attr': 'group-attr',
        'group_dn': 'group-dn',
        'group_filter': 'group-filter',
        'json': 'json',
        'ldap_ca_cert': 'ldap-ca-cert',
        'ldap_enable': 'ldap-enable',
        'ldap_url': 'ldap-url',
        'ldap_anonymous_search': 'ldap_anonymous_search',
        'signing_key_data': 'signing-key-data',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_attribute': 'user-attribute',
        'user_dn': 'user-dn'
    }

    def __init__(self, access_id=None, bind_dn=None, bind_dn_password=None, group_attr=None, group_dn=None, group_filter=None, json=None, ldap_ca_cert=None, ldap_enable=None, ldap_url=None, ldap_anonymous_search=None, signing_key_data=None, token=None, uid_token=None, user_attribute=None, user_dn=None, local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateLdapAuthConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_id = None
        self._bind_dn = None
        self._bind_dn_password = None
        self._group_attr = None
        self._group_dn = None
        self._group_filter = None
        self._json = None
        self._ldap_ca_cert = None
        self._ldap_enable = None
        self._ldap_url = None
        self._ldap_anonymous_search = None
        self._signing_key_data = None
        self._token = None
        self._uid_token = None
        self._user_attribute = None
        self._user_dn = None
        self.discriminator = None

        if access_id is not None:
            self.access_id = access_id
        if bind_dn is not None:
            self.bind_dn = bind_dn
        if bind_dn_password is not None:
            self.bind_dn_password = bind_dn_password
        if group_attr is not None:
            self.group_attr = group_attr
        if group_dn is not None:
            self.group_dn = group_dn
        if group_filter is not None:
            self.group_filter = group_filter
        if json is not None:
            self.json = json
        if ldap_ca_cert is not None:
            self.ldap_ca_cert = ldap_ca_cert
        if ldap_enable is not None:
            self.ldap_enable = ldap_enable
        if ldap_url is not None:
            self.ldap_url = ldap_url
        if ldap_anonymous_search is not None:
            self.ldap_anonymous_search = ldap_anonymous_search
        if signing_key_data is not None:
            self.signing_key_data = signing_key_data
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_attribute is not None:
            self.user_attribute = user_attribute
        if user_dn is not None:
            self.user_dn = user_dn

    @property
    def access_id(self):
        """Gets the access_id of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        The access ID of the Ldap auth method  # noqa: E501

        :return: The access_id of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._access_id

    @access_id.setter
    def access_id(self, access_id):
        """Sets the access_id of this GatewayUpdateLdapAuthConfig.

        The access ID of the Ldap auth method  # noqa: E501

        :param access_id: The access_id of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._access_id = access_id

    @property
    def bind_dn(self):
        """Gets the bind_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Bind DN  # noqa: E501

        :return: The bind_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._bind_dn

    @bind_dn.setter
    def bind_dn(self, bind_dn):
        """Sets the bind_dn of this GatewayUpdateLdapAuthConfig.

        Bind DN  # noqa: E501

        :param bind_dn: The bind_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._bind_dn = bind_dn

    @property
    def bind_dn_password(self):
        """Gets the bind_dn_password of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Bind DN Password  # noqa: E501

        :return: The bind_dn_password of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._bind_dn_password

    @bind_dn_password.setter
    def bind_dn_password(self, bind_dn_password):
        """Sets the bind_dn_password of this GatewayUpdateLdapAuthConfig.

        Bind DN Password  # noqa: E501

        :param bind_dn_password: The bind_dn_password of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._bind_dn_password = bind_dn_password

    @property
    def group_attr(self):
        """Gets the group_attr of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Group Attr  # noqa: E501

        :return: The group_attr of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._group_attr

    @group_attr.setter
    def group_attr(self, group_attr):
        """Sets the group_attr of this GatewayUpdateLdapAuthConfig.

        Group Attr  # noqa: E501

        :param group_attr: The group_attr of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._group_attr = group_attr

    @property
    def group_dn(self):
        """Gets the group_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Group Dn  # noqa: E501

        :return: The group_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._group_dn

    @group_dn.setter
    def group_dn(self, group_dn):
        """Sets the group_dn of this GatewayUpdateLdapAuthConfig.

        Group Dn  # noqa: E501

        :param group_dn: The group_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._group_dn = group_dn

    @property
    def group_filter(self):
        """Gets the group_filter of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Group Filter  # noqa: E501

        :return: The group_filter of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._group_filter

    @group_filter.setter
    def group_filter(self, group_filter):
        """Sets the group_filter of this GatewayUpdateLdapAuthConfig.

        Group Filter  # noqa: E501

        :param group_filter: The group_filter of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._group_filter = group_filter

    @property
    def json(self):
        """Gets the json of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateLdapAuthConfig.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def ldap_ca_cert(self):
        """Gets the ldap_ca_cert of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        LDAP CA Certificate (base64 encoded)  # noqa: E501

        :return: The ldap_ca_cert of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._ldap_ca_cert

    @ldap_ca_cert.setter
    def ldap_ca_cert(self, ldap_ca_cert):
        """Sets the ldap_ca_cert of this GatewayUpdateLdapAuthConfig.

        LDAP CA Certificate (base64 encoded)  # noqa: E501

        :param ldap_ca_cert: The ldap_ca_cert of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._ldap_ca_cert = ldap_ca_cert

    @property
    def ldap_enable(self):
        """Gets the ldap_enable of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Enable Ldap  # noqa: E501

        :return: The ldap_enable of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._ldap_enable

    @ldap_enable.setter
    def ldap_enable(self, ldap_enable):
        """Sets the ldap_enable of this GatewayUpdateLdapAuthConfig.

        Enable Ldap  # noqa: E501

        :param ldap_enable: The ldap_enable of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._ldap_enable = ldap_enable

    @property
    def ldap_url(self):
        """Gets the ldap_url of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        LDAP Server URL, e.g. ldap://planetexpress.com:389  # noqa: E501

        :return: The ldap_url of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._ldap_url

    @ldap_url.setter
    def ldap_url(self, ldap_url):
        """Sets the ldap_url of this GatewayUpdateLdapAuthConfig.

        LDAP Server URL, e.g. ldap://planetexpress.com:389  # noqa: E501

        :param ldap_url: The ldap_url of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._ldap_url = ldap_url

    @property
    def ldap_anonymous_search(self):
        """Gets the ldap_anonymous_search of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Ldap Anonymous Search  # noqa: E501

        :return: The ldap_anonymous_search of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_anonymous_search

    @ldap_anonymous_search.setter
    def ldap_anonymous_search(self, ldap_anonymous_search):
        """Sets the ldap_anonymous_search of this GatewayUpdateLdapAuthConfig.

        Ldap Anonymous Search  # noqa: E501

        :param ldap_anonymous_search: The ldap_anonymous_search of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: bool
        """

        self._ldap_anonymous_search = ldap_anonymous_search

    @property
    def signing_key_data(self):
        """Gets the signing_key_data of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        The private key (base64 encoded), associated with the public key defined in the Ldap auth  # noqa: E501

        :return: The signing_key_data of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._signing_key_data

    @signing_key_data.setter
    def signing_key_data(self, signing_key_data):
        """Sets the signing_key_data of this GatewayUpdateLdapAuthConfig.

        The private key (base64 encoded), associated with the public key defined in the Ldap auth  # noqa: E501

        :param signing_key_data: The signing_key_data of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._signing_key_data = signing_key_data

    @property
    def token(self):
        """Gets the token of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateLdapAuthConfig.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateLdapAuthConfig.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_attribute(self):
        """Gets the user_attribute of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        User Attribute  # noqa: E501

        :return: The user_attribute of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._user_attribute

    @user_attribute.setter
    def user_attribute(self, user_attribute):
        """Sets the user_attribute of this GatewayUpdateLdapAuthConfig.

        User Attribute  # noqa: E501

        :param user_attribute: The user_attribute of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._user_attribute = user_attribute

    @property
    def user_dn(self):
        """Gets the user_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501

        User DN  # noqa: E501

        :return: The user_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._user_dn

    @user_dn.setter
    def user_dn(self, user_dn):
        """Sets the user_dn of this GatewayUpdateLdapAuthConfig.

        User DN  # noqa: E501

        :param user_dn: The user_dn of this GatewayUpdateLdapAuthConfig.  # noqa: E501
        :type: str
        """

        self._user_dn = user_dn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateLdapAuthConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateLdapAuthConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AssocRoleAuthMethod(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'am_name': 'str',
        'case_sensitive': 'str',
        'json': 'bool',
        'role_name': 'str',
        'sub_claims': 'dict(str, str)',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'am_name': 'am-name',
        'case_sensitive': 'case-sensitive',
        'json': 'json',
        'role_name': 'role-name',
        'sub_claims': 'sub-claims',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, am_name=None, case_sensitive=None, json=None, role_name=None, sub_claims=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """AssocRoleAuthMethod - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._am_name = None
        self._case_sensitive = None
        self._json = None
        self._role_name = None
        self._sub_claims = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        self.am_name = am_name
        if case_sensitive is not None:
            self.case_sensitive = case_sensitive
        if json is not None:
            self.json = json
        self.role_name = role_name
        if sub_claims is not None:
            self.sub_claims = sub_claims
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def am_name(self):
        """Gets the am_name of this AssocRoleAuthMethod.  # noqa: E501

        The auth method to associate  # noqa: E501

        :return: The am_name of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: str
        """
        return self._am_name

    @am_name.setter
    def am_name(self, am_name):
        """Sets the am_name of this AssocRoleAuthMethod.

        The auth method to associate  # noqa: E501

        :param am_name: The am_name of this AssocRoleAuthMethod.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and am_name is None:  # noqa: E501
            raise ValueError("Invalid value for `am_name`, must not be `None`")  # noqa: E501

        self._am_name = am_name

    @property
    def case_sensitive(self):
        """Gets the case_sensitive of this AssocRoleAuthMethod.  # noqa: E501


        :return: The case_sensitive of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: str
        """
        return self._case_sensitive

    @case_sensitive.setter
    def case_sensitive(self, case_sensitive):
        """Sets the case_sensitive of this AssocRoleAuthMethod.


        :param case_sensitive: The case_sensitive of this AssocRoleAuthMethod.  # noqa: E501
        :type: str
        """

        self._case_sensitive = case_sensitive

    @property
    def json(self):
        """Gets the json of this AssocRoleAuthMethod.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this AssocRoleAuthMethod.

        Set output format to JSON  # noqa: E501

        :param json: The json of this AssocRoleAuthMethod.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def role_name(self):
        """Gets the role_name of this AssocRoleAuthMethod.  # noqa: E501

        The role to associate  # noqa: E501

        :return: The role_name of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this AssocRoleAuthMethod.

        The role to associate  # noqa: E501

        :param role_name: The role_name of this AssocRoleAuthMethod.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and role_name is None:  # noqa: E501
            raise ValueError("Invalid value for `role_name`, must not be `None`")  # noqa: E501

        self._role_name = role_name

    @property
    def sub_claims(self):
        """Gets the sub_claims of this AssocRoleAuthMethod.  # noqa: E501

        key/val of sub claims, e.g group=admins,developers  # noqa: E501

        :return: The sub_claims of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._sub_claims

    @sub_claims.setter
    def sub_claims(self, sub_claims):
        """Sets the sub_claims of this AssocRoleAuthMethod.

        key/val of sub claims, e.g group=admins,developers  # noqa: E501

        :param sub_claims: The sub_claims of this AssocRoleAuthMethod.  # noqa: E501
        :type: dict(str, str)
        """

        self._sub_claims = sub_claims

    @property
    def token(self):
        """Gets the token of this AssocRoleAuthMethod.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AssocRoleAuthMethod.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this AssocRoleAuthMethod.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this AssocRoleAuthMethod.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this AssocRoleAuthMethod.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this AssocRoleAuthMethod.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this AssocRoleAuthMethod.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssocRoleAuthMethod):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssocRoleAuthMethod):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.target_type_details_input import TargetTypeDetailsInput  # noqa: E501
from akeyless.rest import ApiException

class TestTargetTypeDetailsInput(unittest.TestCase):
    """TargetTypeDetailsInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TargetTypeDetailsInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.target_type_details_input.TargetTypeDetailsInput()  # noqa: E501
        if include_optional :
            return TargetTypeDetailsInput(
                artifactory_admin_apikey = '0', 
                artifactory_admin_username = '0', 
                artifactory_base_url = '0', 
                aws_access_key_id = '0', 
                aws_region = '0', 
                aws_secret_access_key = '0', 
                aws_session_token = '0', 
                azure_client_id = '0', 
                azure_client_secret = '0', 
                azure_tenant_id = '0', 
                chef_server_host_name = '0', 
                chef_server_key = '0', 
                chef_server_port = '0', 
                chef_server_url = '0', 
                chef_server_username = '0', 
                chef_skip_ssl = True, 
                db_host_name = '0', 
                db_name = '0', 
                db_port = '0', 
                db_pwd = '0', 
                db_server_certificates = '0', 
                db_server_name = '0', 
                db_user_name = '0', 
                eks_access_key_id = '0', 
                eks_assume_role = '0', 
                eks_cluster_ca_certificate = '0', 
                eks_cluster_endpoint = '0', 
                eks_cluster_name = '0', 
                eks_region = '0', 
                eks_secret_access_key = '0', 
                gcp_service_account_email = '0', 
                gcp_service_account_key = [
                    56
                    ], 
                gke_cluster_ca_certificate = '0', 
                gke_cluster_endpoint = '0', 
                gke_cluster_name = '0', 
                gke_service_account_key = '0', 
                gke_service_account_name = '0', 
                host = '0', 
                mongodb_atlas = True, 
                mongodb_atlas_api_private_key = '0', 
                mongodb_atlas_api_public_key = '0', 
                mongodb_atlas_project_id = '0', 
                mongodb_db_name = '0', 
                mongodb_default_auth_db = '0', 
                mongodb_host_port = '0', 
                mongodb_password = '0', 
                mongodb_uri_connection = '0', 
                mongodb_uri_options = '0', 
                mongodb_username = '0', 
                password = '0', 
                port = '0', 
                private_key = '0', 
                private_key_password = '0', 
                rabbitmq_server_password = '0', 
                rabbitmq_server_uri = '0', 
                rabbitmq_server_user = '0', 
                sf_account = '0', 
                url = '0', 
                username = '0', 
                venafi_api_key = '0', 
                venafi_base_url = '0', 
                venafi_tpp_password = '0', 
                venafi_tpp_username = '0', 
                venafi_use_tpp = True, 
                venafi_zone = '0'
            )
        else :
            return TargetTypeDetailsInput(
        )

    def testTargetTypeDetailsInput(self):
        """Test TargetTypeDetailsInput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GetPKICertificate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alt_names': 'str',
        'cert_issuer_name': 'str',
        'common_name': 'str',
        'extended_key_usage': 'str',
        'json': 'bool',
        'key_data_base64': 'str',
        'token': 'str',
        'ttl': 'int',
        'uid_token': 'str',
        'uri_sans': 'str'
    }

    attribute_map = {
        'alt_names': 'alt-names',
        'cert_issuer_name': 'cert-issuer-name',
        'common_name': 'common-name',
        'extended_key_usage': 'extended-key-usage',
        'json': 'json',
        'key_data_base64': 'key-data-base64',
        'token': 'token',
        'ttl': 'ttl',
        'uid_token': 'uid-token',
        'uri_sans': 'uri-sans'
    }

    def __init__(self, alt_names=None, cert_issuer_name=None, common_name=None, extended_key_usage=None, json=None, key_data_base64=None, token=None, ttl=None, uid_token=None, uri_sans=None, local_vars_configuration=None):  # noqa: E501
        """GetPKICertificate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alt_names = None
        self._cert_issuer_name = None
        self._common_name = None
        self._extended_key_usage = None
        self._json = None
        self._key_data_base64 = None
        self._token = None
        self._ttl = None
        self._uid_token = None
        self._uri_sans = None
        self.discriminator = None

        if alt_names is not None:
            self.alt_names = alt_names
        self.cert_issuer_name = cert_issuer_name
        if common_name is not None:
            self.common_name = common_name
        if extended_key_usage is not None:
            self.extended_key_usage = extended_key_usage
        if json is not None:
            self.json = json
        if key_data_base64 is not None:
            self.key_data_base64 = key_data_base64
        if token is not None:
            self.token = token
        if ttl is not None:
            self.ttl = ttl
        if uid_token is not None:
            self.uid_token = uid_token
        if uri_sans is not None:
            self.uri_sans = uri_sans

    @property
    def alt_names(self):
        """Gets the alt_names of this GetPKICertificate.  # noqa: E501

        The Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :return: The alt_names of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._alt_names

    @alt_names.setter
    def alt_names(self, alt_names):
        """Sets the alt_names of this GetPKICertificate.

        The Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :param alt_names: The alt_names of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._alt_names = alt_names

    @property
    def cert_issuer_name(self):
        """Gets the cert_issuer_name of this GetPKICertificate.  # noqa: E501

        The name of the PKI certificate issuer  # noqa: E501

        :return: The cert_issuer_name of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._cert_issuer_name

    @cert_issuer_name.setter
    def cert_issuer_name(self, cert_issuer_name):
        """Sets the cert_issuer_name of this GetPKICertificate.

        The name of the PKI certificate issuer  # noqa: E501

        :param cert_issuer_name: The cert_issuer_name of this GetPKICertificate.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and cert_issuer_name is None:  # noqa: E501
            raise ValueError("Invalid value for `cert_issuer_name`, must not be `None`")  # noqa: E501

        self._cert_issuer_name = cert_issuer_name

    @property
    def common_name(self):
        """Gets the common_name of this GetPKICertificate.  # noqa: E501

        The common name to be included in the PKI certificate  # noqa: E501

        :return: The common_name of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """Sets the common_name of this GetPKICertificate.

        The common name to be included in the PKI certificate  # noqa: E501

        :param common_name: The common_name of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._common_name = common_name

    @property
    def extended_key_usage(self):
        """Gets the extended_key_usage of this GetPKICertificate.  # noqa: E501

        A comma-separated list of extended key usage requests which will be used for certificate issuance. Supported values: 'clientauth', 'serverauth'.  # noqa: E501

        :return: The extended_key_usage of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._extended_key_usage

    @extended_key_usage.setter
    def extended_key_usage(self, extended_key_usage):
        """Sets the extended_key_usage of this GetPKICertificate.

        A comma-separated list of extended key usage requests which will be used for certificate issuance. Supported values: 'clientauth', 'serverauth'.  # noqa: E501

        :param extended_key_usage: The extended_key_usage of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._extended_key_usage = extended_key_usage

    @property
    def json(self):
        """Gets the json of this GetPKICertificate.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GetPKICertificate.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GetPKICertificate.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GetPKICertificate.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key_data_base64(self):
        """Gets the key_data_base64 of this GetPKICertificate.  # noqa: E501

        PKI key file contents. If this option is used, the certificate will be printed to stdout  # noqa: E501

        :return: The key_data_base64 of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._key_data_base64

    @key_data_base64.setter
    def key_data_base64(self, key_data_base64):
        """Sets the key_data_base64 of this GetPKICertificate.

        PKI key file contents. If this option is used, the certificate will be printed to stdout  # noqa: E501

        :param key_data_base64: The key_data_base64 of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._key_data_base64 = key_data_base64

    @property
    def token(self):
        """Gets the token of this GetPKICertificate.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GetPKICertificate.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def ttl(self):
        """Gets the ttl of this GetPKICertificate.  # noqa: E501

        Updated certificate lifetime in seconds (must be less than the Certificate Issuer default TTL)  # noqa: E501

        :return: The ttl of this GetPKICertificate.  # noqa: E501
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """Sets the ttl of this GetPKICertificate.

        Updated certificate lifetime in seconds (must be less than the Certificate Issuer default TTL)  # noqa: E501

        :param ttl: The ttl of this GetPKICertificate.  # noqa: E501
        :type: int
        """

        self._ttl = ttl

    @property
    def uid_token(self):
        """Gets the uid_token of this GetPKICertificate.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GetPKICertificate.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def uri_sans(self):
        """Gets the uri_sans of this GetPKICertificate.  # noqa: E501

        The URI Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :return: The uri_sans of this GetPKICertificate.  # noqa: E501
        :rtype: str
        """
        return self._uri_sans

    @uri_sans.setter
    def uri_sans(self, uri_sans):
        """Sets the uri_sans of this GetPKICertificate.

        The URI Subject Alternative Names to be included in the PKI certificate (in a comma-delimited list)  # noqa: E501

        :param uri_sans: The uri_sans of this GetPKICertificate.  # noqa: E501
        :type: str
        """

        self._uri_sans = uri_sans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetPKICertificate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetPKICertificate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AzureADAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_endpoint': 'str',
        'bound_group_ids': 'list[str]',
        'bound_resource_groups': 'list[str]',
        'bound_resource_ids': 'list[str]',
        'bound_resource_names': 'list[str]',
        'bound_resource_providers': 'list[str]',
        'bound_resource_types': 'list[str]',
        'bound_service_principal_ids': 'list[str]',
        'bound_subscription_ids': 'list[str]',
        'bound_tenant_id': 'str',
        'issuer': 'str',
        'jwks_uri': 'str'
    }

    attribute_map = {
        'ad_endpoint': 'ad_endpoint',
        'bound_group_ids': 'bound_group_ids',
        'bound_resource_groups': 'bound_resource_groups',
        'bound_resource_ids': 'bound_resource_ids',
        'bound_resource_names': 'bound_resource_names',
        'bound_resource_providers': 'bound_resource_providers',
        'bound_resource_types': 'bound_resource_types',
        'bound_service_principal_ids': 'bound_service_principal_ids',
        'bound_subscription_ids': 'bound_subscription_ids',
        'bound_tenant_id': 'bound_tenant_id',
        'issuer': 'issuer',
        'jwks_uri': 'jwks_uri'
    }

    def __init__(self, ad_endpoint=None, bound_group_ids=None, bound_resource_groups=None, bound_resource_ids=None, bound_resource_names=None, bound_resource_providers=None, bound_resource_types=None, bound_service_principal_ids=None, bound_subscription_ids=None, bound_tenant_id=None, issuer=None, jwks_uri=None, local_vars_configuration=None):  # noqa: E501
        """AzureADAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ad_endpoint = None
        self._bound_group_ids = None
        self._bound_resource_groups = None
        self._bound_resource_ids = None
        self._bound_resource_names = None
        self._bound_resource_providers = None
        self._bound_resource_types = None
        self._bound_service_principal_ids = None
        self._bound_subscription_ids = None
        self._bound_tenant_id = None
        self._issuer = None
        self._jwks_uri = None
        self.discriminator = None

        if ad_endpoint is not None:
            self.ad_endpoint = ad_endpoint
        if bound_group_ids is not None:
            self.bound_group_ids = bound_group_ids
        if bound_resource_groups is not None:
            self.bound_resource_groups = bound_resource_groups
        if bound_resource_ids is not None:
            self.bound_resource_ids = bound_resource_ids
        if bound_resource_names is not None:
            self.bound_resource_names = bound_resource_names
        if bound_resource_providers is not None:
            self.bound_resource_providers = bound_resource_providers
        if bound_resource_types is not None:
            self.bound_resource_types = bound_resource_types
        if bound_service_principal_ids is not None:
            self.bound_service_principal_ids = bound_service_principal_ids
        if bound_subscription_ids is not None:
            self.bound_subscription_ids = bound_subscription_ids
        if bound_tenant_id is not None:
            self.bound_tenant_id = bound_tenant_id
        if issuer is not None:
            self.issuer = issuer
        if jwks_uri is not None:
            self.jwks_uri = jwks_uri

    @property
    def ad_endpoint(self):
        """Gets the ad_endpoint of this AzureADAccessRules.  # noqa: E501

        The audience in the JWT.  # noqa: E501

        :return: The ad_endpoint of this AzureADAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._ad_endpoint

    @ad_endpoint.setter
    def ad_endpoint(self, ad_endpoint):
        """Sets the ad_endpoint of this AzureADAccessRules.

        The audience in the JWT.  # noqa: E501

        :param ad_endpoint: The ad_endpoint of this AzureADAccessRules.  # noqa: E501
        :type: str
        """

        self._ad_endpoint = ad_endpoint

    @property
    def bound_group_ids(self):
        """Gets the bound_group_ids of this AzureADAccessRules.  # noqa: E501

        The list of group ids that login is restricted to.  # noqa: E501

        :return: The bound_group_ids of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_group_ids

    @bound_group_ids.setter
    def bound_group_ids(self, bound_group_ids):
        """Sets the bound_group_ids of this AzureADAccessRules.

        The list of group ids that login is restricted to.  # noqa: E501

        :param bound_group_ids: The bound_group_ids of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_group_ids = bound_group_ids

    @property
    def bound_resource_groups(self):
        """Gets the bound_resource_groups of this AzureADAccessRules.  # noqa: E501

        The list of resource groups that login is restricted to.  # noqa: E501

        :return: The bound_resource_groups of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_resource_groups

    @bound_resource_groups.setter
    def bound_resource_groups(self, bound_resource_groups):
        """Sets the bound_resource_groups of this AzureADAccessRules.

        The list of resource groups that login is restricted to.  # noqa: E501

        :param bound_resource_groups: The bound_resource_groups of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_resource_groups = bound_resource_groups

    @property
    def bound_resource_ids(self):
        """Gets the bound_resource_ids of this AzureADAccessRules.  # noqa: E501

        The list of full resource ids that the login is restricted to.  # noqa: E501

        :return: The bound_resource_ids of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_resource_ids

    @bound_resource_ids.setter
    def bound_resource_ids(self, bound_resource_ids):
        """Sets the bound_resource_ids of this AzureADAccessRules.

        The list of full resource ids that the login is restricted to.  # noqa: E501

        :param bound_resource_ids: The bound_resource_ids of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_resource_ids = bound_resource_ids

    @property
    def bound_resource_names(self):
        """Gets the bound_resource_names of this AzureADAccessRules.  # noqa: E501

        The list of resource names that the login is restricted to (e.g, a virtual machine name, scale set name, etc).  # noqa: E501

        :return: The bound_resource_names of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_resource_names

    @bound_resource_names.setter
    def bound_resource_names(self, bound_resource_names):
        """Sets the bound_resource_names of this AzureADAccessRules.

        The list of resource names that the login is restricted to (e.g, a virtual machine name, scale set name, etc).  # noqa: E501

        :param bound_resource_names: The bound_resource_names of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_resource_names = bound_resource_names

    @property
    def bound_resource_providers(self):
        """Gets the bound_resource_providers of this AzureADAccessRules.  # noqa: E501

        The list of resource providers that login is restricted to (e.g, Microsoft.Compute, Microsoft.ManagedIdentity, etc).  # noqa: E501

        :return: The bound_resource_providers of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_resource_providers

    @bound_resource_providers.setter
    def bound_resource_providers(self, bound_resource_providers):
        """Sets the bound_resource_providers of this AzureADAccessRules.

        The list of resource providers that login is restricted to (e.g, Microsoft.Compute, Microsoft.ManagedIdentity, etc).  # noqa: E501

        :param bound_resource_providers: The bound_resource_providers of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_resource_providers = bound_resource_providers

    @property
    def bound_resource_types(self):
        """Gets the bound_resource_types of this AzureADAccessRules.  # noqa: E501

        The list of resource types that login is restricted to  (e.g, virtualMachines, userAssignedIdentities, etc).  # noqa: E501

        :return: The bound_resource_types of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_resource_types

    @bound_resource_types.setter
    def bound_resource_types(self, bound_resource_types):
        """Sets the bound_resource_types of this AzureADAccessRules.

        The list of resource types that login is restricted to  (e.g, virtualMachines, userAssignedIdentities, etc).  # noqa: E501

        :param bound_resource_types: The bound_resource_types of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_resource_types = bound_resource_types

    @property
    def bound_service_principal_ids(self):
        """Gets the bound_service_principal_ids of this AzureADAccessRules.  # noqa: E501

        The list of service principal IDs that login is restricted to.  # noqa: E501

        :return: The bound_service_principal_ids of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_service_principal_ids

    @bound_service_principal_ids.setter
    def bound_service_principal_ids(self, bound_service_principal_ids):
        """Sets the bound_service_principal_ids of this AzureADAccessRules.

        The list of service principal IDs that login is restricted to.  # noqa: E501

        :param bound_service_principal_ids: The bound_service_principal_ids of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_service_principal_ids = bound_service_principal_ids

    @property
    def bound_subscription_ids(self):
        """Gets the bound_subscription_ids of this AzureADAccessRules.  # noqa: E501

        The list of subscription IDs that login is restricted to.  # noqa: E501

        :return: The bound_subscription_ids of this AzureADAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_subscription_ids

    @bound_subscription_ids.setter
    def bound_subscription_ids(self, bound_subscription_ids):
        """Sets the bound_subscription_ids of this AzureADAccessRules.

        The list of subscription IDs that login is restricted to.  # noqa: E501

        :param bound_subscription_ids: The bound_subscription_ids of this AzureADAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_subscription_ids = bound_subscription_ids

    @property
    def bound_tenant_id(self):
        """Gets the bound_tenant_id of this AzureADAccessRules.  # noqa: E501

        The tenants id for the Azure Active Directory organization.  # noqa: E501

        :return: The bound_tenant_id of this AzureADAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._bound_tenant_id

    @bound_tenant_id.setter
    def bound_tenant_id(self, bound_tenant_id):
        """Sets the bound_tenant_id of this AzureADAccessRules.

        The tenants id for the Azure Active Directory organization.  # noqa: E501

        :param bound_tenant_id: The bound_tenant_id of this AzureADAccessRules.  # noqa: E501
        :type: str
        """

        self._bound_tenant_id = bound_tenant_id

    @property
    def issuer(self):
        """Gets the issuer of this AzureADAccessRules.  # noqa: E501

        Issuer URL  # noqa: E501

        :return: The issuer of this AzureADAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this AzureADAccessRules.

        Issuer URL  # noqa: E501

        :param issuer: The issuer of this AzureADAccessRules.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def jwks_uri(self):
        """Gets the jwks_uri of this AzureADAccessRules.  # noqa: E501

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :return: The jwks_uri of this AzureADAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._jwks_uri

    @jwks_uri.setter
    def jwks_uri(self, jwks_uri):
        """Sets the jwks_uri of this AzureADAccessRules.

        The URL to the JSON Web Key Set (JWKS) that containing the public keys that should be used to verify any JSON Web Token (JWT) issued by the authorization server.  # noqa: E501

        :param jwks_uri: The jwks_uri of this AzureADAccessRules.  # noqa: E501
        :type: str
        """

        self._jwks_uri = jwks_uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureADAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AzureADAccessRules):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.uid_token_details import UIDTokenDetails  # noqa: E501
from akeyless.rest import ApiException

class TestUIDTokenDetails(unittest.TestCase):
    """UIDTokenDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UIDTokenDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.uid_token_details.UIDTokenDetails()  # noqa: E501
        if include_optional :
            return UIDTokenDetails(
                children = {
                    'key' : akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                        children = {
                            'key' : akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                                comment = '0', 
                                deny_inheritance = True, 
                                deny_rotate = True, 
                                depth = 56, 
                                expired_date = '0', 
                                id = '0', 
                                last_rotate = '0', 
                                revoked = True, 
                                ttl = 56, )
                            }, 
                        comment = '0', 
                        deny_inheritance = True, 
                        deny_rotate = True, 
                        depth = 56, 
                        expired_date = '0', 
                        id = '0', 
                        last_rotate = '0', 
                        revoked = True, 
                        ttl = 56, )
                    }, 
                comment = '0', 
                deny_inheritance = True, 
                deny_rotate = True, 
                depth = 56, 
                expired_date = '0', 
                id = '0', 
                last_rotate = '0', 
                revoked = True, 
                ttl = 56
            )
        else :
            return UIDTokenDetails(
        )

    def testUIDTokenDetails(self):
        """Test UIDTokenDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class Name(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'country': 'list[str]',
        'extra_names': 'list[AttributeTypeAndValue]',
        'locality': 'list[str]',
        'names': 'list[AttributeTypeAndValue]',
        'serial_number': 'str',
        'street_address': 'list[str]'
    }

    attribute_map = {
        'country': 'Country',
        'extra_names': 'ExtraNames',
        'locality': 'Locality',
        'names': 'Names',
        'serial_number': 'SerialNumber',
        'street_address': 'StreetAddress'
    }

    def __init__(self, country=None, extra_names=None, locality=None, names=None, serial_number=None, street_address=None, local_vars_configuration=None):  # noqa: E501
        """Name - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._country = None
        self._extra_names = None
        self._locality = None
        self._names = None
        self._serial_number = None
        self._street_address = None
        self.discriminator = None

        if country is not None:
            self.country = country
        if extra_names is not None:
            self.extra_names = extra_names
        if locality is not None:
            self.locality = locality
        if names is not None:
            self.names = names
        if serial_number is not None:
            self.serial_number = serial_number
        if street_address is not None:
            self.street_address = street_address

    @property
    def country(self):
        """Gets the country of this Name.  # noqa: E501


        :return: The country of this Name.  # noqa: E501
        :rtype: list[str]
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Name.


        :param country: The country of this Name.  # noqa: E501
        :type: list[str]
        """

        self._country = country

    @property
    def extra_names(self):
        """Gets the extra_names of this Name.  # noqa: E501

        ExtraNames contains attributes to be copied, raw, into any marshaled distinguished names. Values override any attributes with the same OID. The ExtraNames field is not populated when parsing, see Names.  # noqa: E501

        :return: The extra_names of this Name.  # noqa: E501
        :rtype: list[AttributeTypeAndValue]
        """
        return self._extra_names

    @extra_names.setter
    def extra_names(self, extra_names):
        """Sets the extra_names of this Name.

        ExtraNames contains attributes to be copied, raw, into any marshaled distinguished names. Values override any attributes with the same OID. The ExtraNames field is not populated when parsing, see Names.  # noqa: E501

        :param extra_names: The extra_names of this Name.  # noqa: E501
        :type: list[AttributeTypeAndValue]
        """

        self._extra_names = extra_names

    @property
    def locality(self):
        """Gets the locality of this Name.  # noqa: E501


        :return: The locality of this Name.  # noqa: E501
        :rtype: list[str]
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this Name.


        :param locality: The locality of this Name.  # noqa: E501
        :type: list[str]
        """

        self._locality = locality

    @property
    def names(self):
        """Gets the names of this Name.  # noqa: E501

        Names contains all parsed attributes. When parsing distinguished names, this can be used to extract non-standard attributes that are not parsed by this package. When marshaling to RDNSequences, the Names field is ignored, see ExtraNames.  # noqa: E501

        :return: The names of this Name.  # noqa: E501
        :rtype: list[AttributeTypeAndValue]
        """
        return self._names

    @names.setter
    def names(self, names):
        """Sets the names of this Name.

        Names contains all parsed attributes. When parsing distinguished names, this can be used to extract non-standard attributes that are not parsed by this package. When marshaling to RDNSequences, the Names field is ignored, see ExtraNames.  # noqa: E501

        :param names: The names of this Name.  # noqa: E501
        :type: list[AttributeTypeAndValue]
        """

        self._names = names

    @property
    def serial_number(self):
        """Gets the serial_number of this Name.  # noqa: E501


        :return: The serial_number of this Name.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this Name.


        :param serial_number: The serial_number of this Name.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def street_address(self):
        """Gets the street_address of this Name.  # noqa: E501


        :return: The street_address of this Name.  # noqa: E501
        :rtype: list[str]
        """
        return self._street_address

    @street_address.setter
    def street_address(self, street_address):
        """Sets the street_address of this Name.


        :param street_address: The street_address of this Name.  # noqa: E501
        :type: list[str]
        """

        self._street_address = street_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Name):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Name):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateRole(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'analytics_access': 'str',
        'audit_access': 'str',
        'gw_analytics_access': 'str',
        'json': 'bool',
        'name': 'str',
        'new_comment': 'str',
        'new_name': 'str',
        'sra_reports_access': 'str',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'analytics_access': 'analytics-access',
        'audit_access': 'audit-access',
        'gw_analytics_access': 'gw-analytics-access',
        'json': 'json',
        'name': 'name',
        'new_comment': 'new-comment',
        'new_name': 'new-name',
        'sra_reports_access': 'sra-reports-access',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, analytics_access=None, audit_access=None, gw_analytics_access=None, json=None, name=None, new_comment='default_comment', new_name=None, sra_reports_access=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UpdateRole - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._analytics_access = None
        self._audit_access = None
        self._gw_analytics_access = None
        self._json = None
        self._name = None
        self._new_comment = None
        self._new_name = None
        self._sra_reports_access = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if analytics_access is not None:
            self.analytics_access = analytics_access
        if audit_access is not None:
            self.audit_access = audit_access
        if gw_analytics_access is not None:
            self.gw_analytics_access = gw_analytics_access
        if json is not None:
            self.json = json
        self.name = name
        if new_comment is not None:
            self.new_comment = new_comment
        if new_name is not None:
            self.new_name = new_name
        if sra_reports_access is not None:
            self.sra_reports_access = sra_reports_access
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def analytics_access(self):
        """Gets the analytics_access of this UpdateRole.  # noqa: E501

        Allow this role to view analytics. Currently only 'none', 'own', 'all' values are supported, allowing associated auth methods to view reports produced by the same auth methods.  # noqa: E501

        :return: The analytics_access of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._analytics_access

    @analytics_access.setter
    def analytics_access(self, analytics_access):
        """Sets the analytics_access of this UpdateRole.

        Allow this role to view analytics. Currently only 'none', 'own', 'all' values are supported, allowing associated auth methods to view reports produced by the same auth methods.  # noqa: E501

        :param analytics_access: The analytics_access of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._analytics_access = analytics_access

    @property
    def audit_access(self):
        """Gets the audit_access of this UpdateRole.  # noqa: E501

        Allow this role to view audit logs. Currently only 'none', 'own' and 'all' values are supported, allowing associated auth methods to view audit logs produced by the same auth methods.  # noqa: E501

        :return: The audit_access of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._audit_access

    @audit_access.setter
    def audit_access(self, audit_access):
        """Sets the audit_access of this UpdateRole.

        Allow this role to view audit logs. Currently only 'none', 'own' and 'all' values are supported, allowing associated auth methods to view audit logs produced by the same auth methods.  # noqa: E501

        :param audit_access: The audit_access of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._audit_access = audit_access

    @property
    def gw_analytics_access(self):
        """Gets the gw_analytics_access of this UpdateRole.  # noqa: E501

        Allow this role to view gw analytics. Currently only 'none', 'own', 'all' values are supported, allowing associated auth methods to view reports produced by the same auth methods.  # noqa: E501

        :return: The gw_analytics_access of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._gw_analytics_access

    @gw_analytics_access.setter
    def gw_analytics_access(self, gw_analytics_access):
        """Sets the gw_analytics_access of this UpdateRole.

        Allow this role to view gw analytics. Currently only 'none', 'own', 'all' values are supported, allowing associated auth methods to view reports produced by the same auth methods.  # noqa: E501

        :param gw_analytics_access: The gw_analytics_access of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._gw_analytics_access = gw_analytics_access

    @property
    def json(self):
        """Gets the json of this UpdateRole.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateRole.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateRole.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateRole.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this UpdateRole.  # noqa: E501

        Role name  # noqa: E501

        :return: The name of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateRole.

        Role name  # noqa: E501

        :param name: The name of this UpdateRole.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_comment(self):
        """Gets the new_comment of this UpdateRole.  # noqa: E501

        New comment about the role  # noqa: E501

        :return: The new_comment of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._new_comment

    @new_comment.setter
    def new_comment(self, new_comment):
        """Sets the new_comment of this UpdateRole.

        New comment about the role  # noqa: E501

        :param new_comment: The new_comment of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._new_comment = new_comment

    @property
    def new_name(self):
        """Gets the new_name of this UpdateRole.  # noqa: E501

        New Role name  # noqa: E501

        :return: The new_name of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateRole.

        New Role name  # noqa: E501

        :param new_name: The new_name of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def sra_reports_access(self):
        """Gets the sra_reports_access of this UpdateRole.  # noqa: E501

        Allow this role to view SRA Clusters. Currently only 'none', 'own', 'all' values are supported.  # noqa: E501

        :return: The sra_reports_access of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._sra_reports_access

    @sra_reports_access.setter
    def sra_reports_access(self, sra_reports_access):
        """Sets the sra_reports_access of this UpdateRole.

        Allow this role to view SRA Clusters. Currently only 'none', 'own', 'all' values are supported.  # noqa: E501

        :param sra_reports_access: The sra_reports_access of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._sra_reports_access = sra_reports_access

    @property
    def token(self):
        """Gets the token of this UpdateRole.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateRole.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateRole.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateRole.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateRole.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateRole.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateRole):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateRole):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class SSHCertificateIssueDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed_domains': 'list[str]',
        'allowed_user_key_lengths': 'dict(str, int)',
        'allowed_users': 'list[str]',
        'cert_type': 'int',
        'critical_options': 'dict(str, str)',
        'extensions': 'dict(str, str)',
        'principals': 'list[str]',
        'static_key_id': 'str'
    }

    attribute_map = {
        'allowed_domains': 'allowed_domains',
        'allowed_user_key_lengths': 'allowed_user_key_lengths',
        'allowed_users': 'allowed_users',
        'cert_type': 'cert_type',
        'critical_options': 'critical_options',
        'extensions': 'extensions',
        'principals': 'principals',
        'static_key_id': 'static_key_id'
    }

    def __init__(self, allowed_domains=None, allowed_user_key_lengths=None, allowed_users=None, cert_type=None, critical_options=None, extensions=None, principals=None, static_key_id=None, local_vars_configuration=None):  # noqa: E501
        """SSHCertificateIssueDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed_domains = None
        self._allowed_user_key_lengths = None
        self._allowed_users = None
        self._cert_type = None
        self._critical_options = None
        self._extensions = None
        self._principals = None
        self._static_key_id = None
        self.discriminator = None

        if allowed_domains is not None:
            self.allowed_domains = allowed_domains
        if allowed_user_key_lengths is not None:
            self.allowed_user_key_lengths = allowed_user_key_lengths
        if allowed_users is not None:
            self.allowed_users = allowed_users
        if cert_type is not None:
            self.cert_type = cert_type
        if critical_options is not None:
            self.critical_options = critical_options
        if extensions is not None:
            self.extensions = extensions
        if principals is not None:
            self.principals = principals
        if static_key_id is not None:
            self.static_key_id = static_key_id

    @property
    def allowed_domains(self):
        """Gets the allowed_domains of this SSHCertificateIssueDetails.  # noqa: E501

        Relevant for host certificate  # noqa: E501

        :return: The allowed_domains of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_domains

    @allowed_domains.setter
    def allowed_domains(self, allowed_domains):
        """Sets the allowed_domains of this SSHCertificateIssueDetails.

        Relevant for host certificate  # noqa: E501

        :param allowed_domains: The allowed_domains of this SSHCertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._allowed_domains = allowed_domains

    @property
    def allowed_user_key_lengths(self):
        """Gets the allowed_user_key_lengths of this SSHCertificateIssueDetails.  # noqa: E501


        :return: The allowed_user_key_lengths of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._allowed_user_key_lengths

    @allowed_user_key_lengths.setter
    def allowed_user_key_lengths(self, allowed_user_key_lengths):
        """Sets the allowed_user_key_lengths of this SSHCertificateIssueDetails.


        :param allowed_user_key_lengths: The allowed_user_key_lengths of this SSHCertificateIssueDetails.  # noqa: E501
        :type: dict(str, int)
        """

        self._allowed_user_key_lengths = allowed_user_key_lengths

    @property
    def allowed_users(self):
        """Gets the allowed_users of this SSHCertificateIssueDetails.  # noqa: E501

        Relevant for user certificate  # noqa: E501

        :return: The allowed_users of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_users

    @allowed_users.setter
    def allowed_users(self, allowed_users):
        """Sets the allowed_users of this SSHCertificateIssueDetails.

        Relevant for user certificate  # noqa: E501

        :param allowed_users: The allowed_users of this SSHCertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._allowed_users = allowed_users

    @property
    def cert_type(self):
        """Gets the cert_type of this SSHCertificateIssueDetails.  # noqa: E501


        :return: The cert_type of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: int
        """
        return self._cert_type

    @cert_type.setter
    def cert_type(self, cert_type):
        """Sets the cert_type of this SSHCertificateIssueDetails.


        :param cert_type: The cert_type of this SSHCertificateIssueDetails.  # noqa: E501
        :type: int
        """

        self._cert_type = cert_type

    @property
    def critical_options(self):
        """Gets the critical_options of this SSHCertificateIssueDetails.  # noqa: E501


        :return: The critical_options of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._critical_options

    @critical_options.setter
    def critical_options(self, critical_options):
        """Sets the critical_options of this SSHCertificateIssueDetails.


        :param critical_options: The critical_options of this SSHCertificateIssueDetails.  # noqa: E501
        :type: dict(str, str)
        """

        self._critical_options = critical_options

    @property
    def extensions(self):
        """Gets the extensions of this SSHCertificateIssueDetails.  # noqa: E501


        :return: The extensions of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this SSHCertificateIssueDetails.


        :param extensions: The extensions of this SSHCertificateIssueDetails.  # noqa: E501
        :type: dict(str, str)
        """

        self._extensions = extensions

    @property
    def principals(self):
        """Gets the principals of this SSHCertificateIssueDetails.  # noqa: E501


        :return: The principals of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: list[str]
        """
        return self._principals

    @principals.setter
    def principals(self, principals):
        """Sets the principals of this SSHCertificateIssueDetails.


        :param principals: The principals of this SSHCertificateIssueDetails.  # noqa: E501
        :type: list[str]
        """

        self._principals = principals

    @property
    def static_key_id(self):
        """Gets the static_key_id of this SSHCertificateIssueDetails.  # noqa: E501

        In case it is empty, the key ID will be combination of user identifiers and a random string  # noqa: E501

        :return: The static_key_id of this SSHCertificateIssueDetails.  # noqa: E501
        :rtype: str
        """
        return self._static_key_id

    @static_key_id.setter
    def static_key_id(self, static_key_id):
        """Sets the static_key_id of this SSHCertificateIssueDetails.

        In case it is empty, the key ID will be combination of user identifiers and a random string  # noqa: E501

        :param static_key_id: The static_key_id of this SSHCertificateIssueDetails.  # noqa: E501
        :type: str
        """

        self._static_key_id = static_key_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SSHCertificateIssueDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SSHCertificateIssueDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.managed_key_target_info import ManagedKeyTargetInfo  # noqa: E501
from akeyless.rest import ApiException

class TestManagedKeyTargetInfo(unittest.TestCase):
    """ManagedKeyTargetInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ManagedKeyTargetInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.managed_key_target_info.ManagedKeyTargetInfo()  # noqa: E501
        if include_optional :
            return ManagedKeyTargetInfo(
                external_kms_id = akeyless.models.external_kms_key_id.ExternalKMSKeyId(
                    key_id = '0', 
                    key_reference = '0', ), 
                key_purpose = [
                    '0'
                    ], 
                key_statuses = [
                    akeyless.models.managed_key_status_info.ManagedKeyStatusInfo(
                        key_id = 56, 
                        last_error = '0', 
                        last_status = '0', )
                    ], 
                target_assoc_id = '0'
            )
        else :
            return ManagedKeyTargetInfo(
        )

    def testManagedKeyTargetInfo(self):
        """Test ManagedKeyTargetInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UidRotateToken(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fork': 'bool',
        'json': 'bool',
        'send_manual_ack_token': 'str',
        'uid_token': 'str',
        'with_manual_ack': 'bool'
    }

    attribute_map = {
        'fork': 'fork',
        'json': 'json',
        'send_manual_ack_token': 'send-manual-ack-token',
        'uid_token': 'uid-token',
        'with_manual_ack': 'with-manual-ack'
    }

    def __init__(self, fork=None, json=None, send_manual_ack_token=None, uid_token=None, with_manual_ack=None, local_vars_configuration=None):  # noqa: E501
        """UidRotateToken - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._fork = None
        self._json = None
        self._send_manual_ack_token = None
        self._uid_token = None
        self._with_manual_ack = None
        self.discriminator = None

        if fork is not None:
            self.fork = fork
        if json is not None:
            self.json = json
        if send_manual_ack_token is not None:
            self.send_manual_ack_token = send_manual_ack_token
        if uid_token is not None:
            self.uid_token = uid_token
        if with_manual_ack is not None:
            self.with_manual_ack = with_manual_ack

    @property
    def fork(self):
        """Gets the fork of this UidRotateToken.  # noqa: E501

        Create a new child token with default parameters  # noqa: E501

        :return: The fork of this UidRotateToken.  # noqa: E501
        :rtype: bool
        """
        return self._fork

    @fork.setter
    def fork(self, fork):
        """Sets the fork of this UidRotateToken.

        Create a new child token with default parameters  # noqa: E501

        :param fork: The fork of this UidRotateToken.  # noqa: E501
        :type: bool
        """

        self._fork = fork

    @property
    def json(self):
        """Gets the json of this UidRotateToken.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UidRotateToken.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UidRotateToken.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UidRotateToken.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def send_manual_ack_token(self):
        """Gets the send_manual_ack_token of this UidRotateToken.  # noqa: E501

        The new rotated token to send manual ack for (with uid-token=the-orig-token)  # noqa: E501

        :return: The send_manual_ack_token of this UidRotateToken.  # noqa: E501
        :rtype: str
        """
        return self._send_manual_ack_token

    @send_manual_ack_token.setter
    def send_manual_ack_token(self, send_manual_ack_token):
        """Sets the send_manual_ack_token of this UidRotateToken.

        The new rotated token to send manual ack for (with uid-token=the-orig-token)  # noqa: E501

        :param send_manual_ack_token: The send_manual_ack_token of this UidRotateToken.  # noqa: E501
        :type: str
        """

        self._send_manual_ack_token = send_manual_ack_token

    @property
    def uid_token(self):
        """Gets the uid_token of this UidRotateToken.  # noqa: E501

        The Universal identity token  # noqa: E501

        :return: The uid_token of this UidRotateToken.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UidRotateToken.

        The Universal identity token  # noqa: E501

        :param uid_token: The uid_token of this UidRotateToken.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def with_manual_ack(self):
        """Gets the with_manual_ack of this UidRotateToken.  # noqa: E501

        Disable automatic ack  # noqa: E501

        :return: The with_manual_ack of this UidRotateToken.  # noqa: E501
        :rtype: bool
        """
        return self._with_manual_ack

    @with_manual_ack.setter
    def with_manual_ack(self, with_manual_ack):
        """Sets the with_manual_ack of this UidRotateToken.

        Disable automatic ack  # noqa: E501

        :param with_manual_ack: The with_manual_ack of this UidRotateToken.  # noqa: E501
        :type: bool
        """

        self._with_manual_ack = with_manual_ack

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UidRotateToken):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UidRotateToken):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateEventForwarder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admin_name': 'str',
        'admin_pwd': 'str',
        'comment': 'str',
        'email_to': 'str',
        'event_source_locations': 'list[str]',
        'event_source_type': 'str',
        'event_types': 'list[str]',
        'every': 'str',
        'forwarder_type': 'str',
        'host': 'str',
        'json': 'bool',
        'key': 'str',
        'name': 'str',
        'runner_type': 'str',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'admin_name': 'admin-name',
        'admin_pwd': 'admin-pwd',
        'comment': 'comment',
        'email_to': 'email-to',
        'event_source_locations': 'event-source-locations',
        'event_source_type': 'event-source-type',
        'event_types': 'event-types',
        'every': 'every',
        'forwarder_type': 'forwarder-type',
        'host': 'host',
        'json': 'json',
        'key': 'key',
        'name': 'name',
        'runner_type': 'runner-type',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, admin_name=None, admin_pwd=None, comment=None, email_to=None, event_source_locations=None, event_source_type='item', event_types=None, every=None, forwarder_type=None, host=None, json=None, key=None, name=None, runner_type=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """CreateEventForwarder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admin_name = None
        self._admin_pwd = None
        self._comment = None
        self._email_to = None
        self._event_source_locations = None
        self._event_source_type = None
        self._event_types = None
        self._every = None
        self._forwarder_type = None
        self._host = None
        self._json = None
        self._key = None
        self._name = None
        self._runner_type = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if admin_name is not None:
            self.admin_name = admin_name
        if admin_pwd is not None:
            self.admin_pwd = admin_pwd
        if comment is not None:
            self.comment = comment
        if email_to is not None:
            self.email_to = email_to
        self.event_source_locations = event_source_locations
        if event_source_type is not None:
            self.event_source_type = event_source_type
        if event_types is not None:
            self.event_types = event_types
        if every is not None:
            self.every = every
        self.forwarder_type = forwarder_type
        if host is not None:
            self.host = host
        if json is not None:
            self.json = json
        if key is not None:
            self.key = key
        self.name = name
        self.runner_type = runner_type
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def admin_name(self):
        """Gets the admin_name of this CreateEventForwarder.  # noqa: E501

        Workstation Admin Name  # noqa: E501

        :return: The admin_name of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._admin_name

    @admin_name.setter
    def admin_name(self, admin_name):
        """Sets the admin_name of this CreateEventForwarder.

        Workstation Admin Name  # noqa: E501

        :param admin_name: The admin_name of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._admin_name = admin_name

    @property
    def admin_pwd(self):
        """Gets the admin_pwd of this CreateEventForwarder.  # noqa: E501

        Workstation Admin password  # noqa: E501

        :return: The admin_pwd of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._admin_pwd

    @admin_pwd.setter
    def admin_pwd(self, admin_pwd):
        """Sets the admin_pwd of this CreateEventForwarder.

        Workstation Admin password  # noqa: E501

        :param admin_pwd: The admin_pwd of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._admin_pwd = admin_pwd

    @property
    def comment(self):
        """Gets the comment of this CreateEventForwarder.  # noqa: E501

        Comment about the EventForwarder  # noqa: E501

        :return: The comment of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateEventForwarder.

        Comment about the EventForwarder  # noqa: E501

        :param comment: The comment of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def email_to(self):
        """Gets the email_to of this CreateEventForwarder.  # noqa: E501

        A comma seperated list of email addresses to send event to (relevant only for \\\"email\\\" Event Forwarder)  # noqa: E501

        :return: The email_to of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._email_to

    @email_to.setter
    def email_to(self, email_to):
        """Sets the email_to of this CreateEventForwarder.

        A comma seperated list of email addresses to send event to (relevant only for \\\"email\\\" Event Forwarder)  # noqa: E501

        :param email_to: The email_to of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._email_to = email_to

    @property
    def event_source_locations(self):
        """Gets the event_source_locations of this CreateEventForwarder.  # noqa: E501

        Event sources  # noqa: E501

        :return: The event_source_locations of this CreateEventForwarder.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_source_locations

    @event_source_locations.setter
    def event_source_locations(self, event_source_locations):
        """Sets the event_source_locations of this CreateEventForwarder.

        Event sources  # noqa: E501

        :param event_source_locations: The event_source_locations of this CreateEventForwarder.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and event_source_locations is None:  # noqa: E501
            raise ValueError("Invalid value for `event_source_locations`, must not be `None`")  # noqa: E501

        self._event_source_locations = event_source_locations

    @property
    def event_source_type(self):
        """Gets the event_source_type of this CreateEventForwarder.  # noqa: E501

        Event Source type [item, target]  # noqa: E501

        :return: The event_source_type of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._event_source_type

    @event_source_type.setter
    def event_source_type(self, event_source_type):
        """Sets the event_source_type of this CreateEventForwarder.

        Event Source type [item, target]  # noqa: E501

        :param event_source_type: The event_source_type of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._event_source_type = event_source_type

    @property
    def event_types(self):
        """Gets the event_types of this CreateEventForwarder.  # noqa: E501

        Event types  # noqa: E501

        :return: The event_types of this CreateEventForwarder.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this CreateEventForwarder.

        Event types  # noqa: E501

        :param event_types: The event_types of this CreateEventForwarder.  # noqa: E501
        :type: list[str]
        """

        self._event_types = event_types

    @property
    def every(self):
        """Gets the every of this CreateEventForwarder.  # noqa: E501

        Rate of periodic runner repetition in hours  # noqa: E501

        :return: The every of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._every

    @every.setter
    def every(self, every):
        """Sets the every of this CreateEventForwarder.

        Rate of periodic runner repetition in hours  # noqa: E501

        :param every: The every of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._every = every

    @property
    def forwarder_type(self):
        """Gets the forwarder_type of this CreateEventForwarder.  # noqa: E501


        :return: The forwarder_type of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._forwarder_type

    @forwarder_type.setter
    def forwarder_type(self, forwarder_type):
        """Sets the forwarder_type of this CreateEventForwarder.


        :param forwarder_type: The forwarder_type of this CreateEventForwarder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and forwarder_type is None:  # noqa: E501
            raise ValueError("Invalid value for `forwarder_type`, must not be `None`")  # noqa: E501

        self._forwarder_type = forwarder_type

    @property
    def host(self):
        """Gets the host of this CreateEventForwarder.  # noqa: E501

        Workstation Host  # noqa: E501

        :return: The host of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this CreateEventForwarder.

        Workstation Host  # noqa: E501

        :param host: The host of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def json(self):
        """Gets the json of this CreateEventForwarder.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateEventForwarder.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateEventForwarder.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateEventForwarder.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key(self):
        """Gets the key of this CreateEventForwarder.  # noqa: E501

        The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this CreateEventForwarder.

        The name of a key that used to encrypt the EventForwarder secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this CreateEventForwarder.  # noqa: E501

        EventForwarder name  # noqa: E501

        :return: The name of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateEventForwarder.

        EventForwarder name  # noqa: E501

        :param name: The name of this CreateEventForwarder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def runner_type(self):
        """Gets the runner_type of this CreateEventForwarder.  # noqa: E501


        :return: The runner_type of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._runner_type

    @runner_type.setter
    def runner_type(self, runner_type):
        """Sets the runner_type of this CreateEventForwarder.


        :param runner_type: The runner_type of this CreateEventForwarder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and runner_type is None:  # noqa: E501
            raise ValueError("Invalid value for `runner_type`, must not be `None`")  # noqa: E501

        self._runner_type = runner_type

    @property
    def token(self):
        """Gets the token of this CreateEventForwarder.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateEventForwarder.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateEventForwarder.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateEventForwarder.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateEventForwarder.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateEventForwarder.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateEventForwarder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateEventForwarder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ClassicKeyStatusInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'error_date': 'datetime',
        'last_error': 'str',
        'last_status': 'str',
        'version': 'int'
    }

    attribute_map = {
        'error_date': 'error_date',
        'last_error': 'last_error',
        'last_status': 'last_status',
        'version': 'version'
    }

    def __init__(self, error_date=None, last_error=None, last_status=None, version=None, local_vars_configuration=None):  # noqa: E501
        """ClassicKeyStatusInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error_date = None
        self._last_error = None
        self._last_status = None
        self._version = None
        self.discriminator = None

        if error_date is not None:
            self.error_date = error_date
        if last_error is not None:
            self.last_error = last_error
        if last_status is not None:
            self.last_status = last_status
        if version is not None:
            self.version = version

    @property
    def error_date(self):
        """Gets the error_date of this ClassicKeyStatusInfo.  # noqa: E501


        :return: The error_date of this ClassicKeyStatusInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._error_date

    @error_date.setter
    def error_date(self, error_date):
        """Sets the error_date of this ClassicKeyStatusInfo.


        :param error_date: The error_date of this ClassicKeyStatusInfo.  # noqa: E501
        :type: datetime
        """

        self._error_date = error_date

    @property
    def last_error(self):
        """Gets the last_error of this ClassicKeyStatusInfo.  # noqa: E501


        :return: The last_error of this ClassicKeyStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_error

    @last_error.setter
    def last_error(self, last_error):
        """Sets the last_error of this ClassicKeyStatusInfo.


        :param last_error: The last_error of this ClassicKeyStatusInfo.  # noqa: E501
        :type: str
        """

        self._last_error = last_error

    @property
    def last_status(self):
        """Gets the last_status of this ClassicKeyStatusInfo.  # noqa: E501

        ClassicKeyTargetStatus defines status of classic key target  # noqa: E501

        :return: The last_status of this ClassicKeyStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this ClassicKeyStatusInfo.

        ClassicKeyTargetStatus defines status of classic key target  # noqa: E501

        :param last_status: The last_status of this ClassicKeyStatusInfo.  # noqa: E501
        :type: str
        """

        self._last_status = last_status

    @property
    def version(self):
        """Gets the version of this ClassicKeyStatusInfo.  # noqa: E501


        :return: The version of this ClassicKeyStatusInfo.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ClassicKeyStatusInfo.


        :param version: The version of this ClassicKeyStatusInfo.  # noqa: E501
        :type: int
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassicKeyStatusInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassicKeyStatusInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateAuthMethodHuawei(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_expires': 'int',
        'auth_url': 'str',
        'bound_domain_id': 'list[str]',
        'bound_domain_name': 'list[str]',
        'bound_ips': 'list[str]',
        'bound_tenant_id': 'list[str]',
        'bound_tenant_name': 'list[str]',
        'bound_user_id': 'list[str]',
        'bound_user_name': 'list[str]',
        'force_sub_claims': 'bool',
        'gw_bound_ips': 'list[str]',
        'json': 'bool',
        'jwt_ttl': 'int',
        'name': 'str',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'access_expires': 'access-expires',
        'auth_url': 'auth-url',
        'bound_domain_id': 'bound-domain-id',
        'bound_domain_name': 'bound-domain-name',
        'bound_ips': 'bound-ips',
        'bound_tenant_id': 'bound-tenant-id',
        'bound_tenant_name': 'bound-tenant-name',
        'bound_user_id': 'bound-user-id',
        'bound_user_name': 'bound-user-name',
        'force_sub_claims': 'force-sub-claims',
        'gw_bound_ips': 'gw-bound-ips',
        'json': 'json',
        'jwt_ttl': 'jwt-ttl',
        'name': 'name',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, access_expires=0, auth_url='https://iam.myhwclouds.com:443/v3', bound_domain_id=None, bound_domain_name=None, bound_ips=None, bound_tenant_id=None, bound_tenant_name=None, bound_user_id=None, bound_user_name=None, force_sub_claims=None, gw_bound_ips=None, json=None, jwt_ttl=None, name=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """CreateAuthMethodHuawei - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_expires = None
        self._auth_url = None
        self._bound_domain_id = None
        self._bound_domain_name = None
        self._bound_ips = None
        self._bound_tenant_id = None
        self._bound_tenant_name = None
        self._bound_user_id = None
        self._bound_user_name = None
        self._force_sub_claims = None
        self._gw_bound_ips = None
        self._json = None
        self._jwt_ttl = None
        self._name = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if access_expires is not None:
            self.access_expires = access_expires
        if auth_url is not None:
            self.auth_url = auth_url
        if bound_domain_id is not None:
            self.bound_domain_id = bound_domain_id
        if bound_domain_name is not None:
            self.bound_domain_name = bound_domain_name
        if bound_ips is not None:
            self.bound_ips = bound_ips
        if bound_tenant_id is not None:
            self.bound_tenant_id = bound_tenant_id
        if bound_tenant_name is not None:
            self.bound_tenant_name = bound_tenant_name
        if bound_user_id is not None:
            self.bound_user_id = bound_user_id
        if bound_user_name is not None:
            self.bound_user_name = bound_user_name
        if force_sub_claims is not None:
            self.force_sub_claims = force_sub_claims
        if gw_bound_ips is not None:
            self.gw_bound_ips = gw_bound_ips
        if json is not None:
            self.json = json
        if jwt_ttl is not None:
            self.jwt_ttl = jwt_ttl
        self.name = name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def access_expires(self):
        """Gets the access_expires of this CreateAuthMethodHuawei.  # noqa: E501

        Access expiration date in Unix timestamp (select 0 for access without expiry date)  # noqa: E501

        :return: The access_expires of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: int
        """
        return self._access_expires

    @access_expires.setter
    def access_expires(self, access_expires):
        """Sets the access_expires of this CreateAuthMethodHuawei.

        Access expiration date in Unix timestamp (select 0 for access without expiry date)  # noqa: E501

        :param access_expires: The access_expires of this CreateAuthMethodHuawei.  # noqa: E501
        :type: int
        """

        self._access_expires = access_expires

    @property
    def auth_url(self):
        """Gets the auth_url of this CreateAuthMethodHuawei.  # noqa: E501

        sts URL  # noqa: E501

        :return: The auth_url of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: str
        """
        return self._auth_url

    @auth_url.setter
    def auth_url(self, auth_url):
        """Sets the auth_url of this CreateAuthMethodHuawei.

        sts URL  # noqa: E501

        :param auth_url: The auth_url of this CreateAuthMethodHuawei.  # noqa: E501
        :type: str
        """

        self._auth_url = auth_url

    @property
    def bound_domain_id(self):
        """Gets the bound_domain_id of this CreateAuthMethodHuawei.  # noqa: E501

        A list of domain IDs that the access is restricted to  # noqa: E501

        :return: The bound_domain_id of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_domain_id

    @bound_domain_id.setter
    def bound_domain_id(self, bound_domain_id):
        """Sets the bound_domain_id of this CreateAuthMethodHuawei.

        A list of domain IDs that the access is restricted to  # noqa: E501

        :param bound_domain_id: The bound_domain_id of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_domain_id = bound_domain_id

    @property
    def bound_domain_name(self):
        """Gets the bound_domain_name of this CreateAuthMethodHuawei.  # noqa: E501

        A list of domain names that the access is restricted to  # noqa: E501

        :return: The bound_domain_name of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_domain_name

    @bound_domain_name.setter
    def bound_domain_name(self, bound_domain_name):
        """Sets the bound_domain_name of this CreateAuthMethodHuawei.

        A list of domain names that the access is restricted to  # noqa: E501

        :param bound_domain_name: The bound_domain_name of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_domain_name = bound_domain_name

    @property
    def bound_ips(self):
        """Gets the bound_ips of this CreateAuthMethodHuawei.  # noqa: E501

        A CIDR whitelist with the IPs that the access is restricted to  # noqa: E501

        :return: The bound_ips of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_ips

    @bound_ips.setter
    def bound_ips(self, bound_ips):
        """Sets the bound_ips of this CreateAuthMethodHuawei.

        A CIDR whitelist with the IPs that the access is restricted to  # noqa: E501

        :param bound_ips: The bound_ips of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_ips = bound_ips

    @property
    def bound_tenant_id(self):
        """Gets the bound_tenant_id of this CreateAuthMethodHuawei.  # noqa: E501

        A list of full tenant ids that the access is restricted to  # noqa: E501

        :return: The bound_tenant_id of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_tenant_id

    @bound_tenant_id.setter
    def bound_tenant_id(self, bound_tenant_id):
        """Sets the bound_tenant_id of this CreateAuthMethodHuawei.

        A list of full tenant ids that the access is restricted to  # noqa: E501

        :param bound_tenant_id: The bound_tenant_id of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_tenant_id = bound_tenant_id

    @property
    def bound_tenant_name(self):
        """Gets the bound_tenant_name of this CreateAuthMethodHuawei.  # noqa: E501

        A list of full tenant names that the access is restricted to  # noqa: E501

        :return: The bound_tenant_name of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_tenant_name

    @bound_tenant_name.setter
    def bound_tenant_name(self, bound_tenant_name):
        """Sets the bound_tenant_name of this CreateAuthMethodHuawei.

        A list of full tenant names that the access is restricted to  # noqa: E501

        :param bound_tenant_name: The bound_tenant_name of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_tenant_name = bound_tenant_name

    @property
    def bound_user_id(self):
        """Gets the bound_user_id of this CreateAuthMethodHuawei.  # noqa: E501

        A list of full user ids that the access is restricted to  # noqa: E501

        :return: The bound_user_id of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_user_id

    @bound_user_id.setter
    def bound_user_id(self, bound_user_id):
        """Sets the bound_user_id of this CreateAuthMethodHuawei.

        A list of full user ids that the access is restricted to  # noqa: E501

        :param bound_user_id: The bound_user_id of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_user_id = bound_user_id

    @property
    def bound_user_name(self):
        """Gets the bound_user_name of this CreateAuthMethodHuawei.  # noqa: E501

        A list of full user-name that the access is restricted to  # noqa: E501

        :return: The bound_user_name of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_user_name

    @bound_user_name.setter
    def bound_user_name(self, bound_user_name):
        """Sets the bound_user_name of this CreateAuthMethodHuawei.

        A list of full user-name that the access is restricted to  # noqa: E501

        :param bound_user_name: The bound_user_name of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._bound_user_name = bound_user_name

    @property
    def force_sub_claims(self):
        """Gets the force_sub_claims of this CreateAuthMethodHuawei.  # noqa: E501

        if true: enforce role-association must include sub claims  # noqa: E501

        :return: The force_sub_claims of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: bool
        """
        return self._force_sub_claims

    @force_sub_claims.setter
    def force_sub_claims(self, force_sub_claims):
        """Sets the force_sub_claims of this CreateAuthMethodHuawei.

        if true: enforce role-association must include sub claims  # noqa: E501

        :param force_sub_claims: The force_sub_claims of this CreateAuthMethodHuawei.  # noqa: E501
        :type: bool
        """

        self._force_sub_claims = force_sub_claims

    @property
    def gw_bound_ips(self):
        """Gets the gw_bound_ips of this CreateAuthMethodHuawei.  # noqa: E501

        A CIDR whitelist with the GW IPs that the access is restricted to  # noqa: E501

        :return: The gw_bound_ips of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: list[str]
        """
        return self._gw_bound_ips

    @gw_bound_ips.setter
    def gw_bound_ips(self, gw_bound_ips):
        """Sets the gw_bound_ips of this CreateAuthMethodHuawei.

        A CIDR whitelist with the GW IPs that the access is restricted to  # noqa: E501

        :param gw_bound_ips: The gw_bound_ips of this CreateAuthMethodHuawei.  # noqa: E501
        :type: list[str]
        """

        self._gw_bound_ips = gw_bound_ips

    @property
    def json(self):
        """Gets the json of this CreateAuthMethodHuawei.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateAuthMethodHuawei.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateAuthMethodHuawei.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def jwt_ttl(self):
        """Gets the jwt_ttl of this CreateAuthMethodHuawei.  # noqa: E501

        Jwt TTL  # noqa: E501

        :return: The jwt_ttl of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl

    @jwt_ttl.setter
    def jwt_ttl(self, jwt_ttl):
        """Sets the jwt_ttl of this CreateAuthMethodHuawei.

        Jwt TTL  # noqa: E501

        :param jwt_ttl: The jwt_ttl of this CreateAuthMethodHuawei.  # noqa: E501
        :type: int
        """

        self._jwt_ttl = jwt_ttl

    @property
    def name(self):
        """Gets the name of this CreateAuthMethodHuawei.  # noqa: E501

        Auth Method name  # noqa: E501

        :return: The name of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateAuthMethodHuawei.

        Auth Method name  # noqa: E501

        :param name: The name of this CreateAuthMethodHuawei.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def token(self):
        """Gets the token of this CreateAuthMethodHuawei.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateAuthMethodHuawei.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateAuthMethodHuawei.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateAuthMethodHuawei.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateAuthMethodHuawei.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateAuthMethodHuawei.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateAuthMethodHuawei.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAuthMethodHuawei):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateAuthMethodHuawei):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayGetK8SAuthConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'am_token_expiration': 'int',
        'auth_method_access_id': 'str',
        'auth_method_prv_key_pem': 'str',
        'cluster_api_type': 'str',
        'disable_iss_validation': 'bool',
        'id': 'str',
        'k8s_ca_cert': 'str',
        'k8s_host': 'str',
        'k8s_issuer': 'str',
        'k8s_pub_keys_pem': 'list[str]',
        'k8s_token_reviewer_jwt': 'str',
        'name': 'str',
        'protection_key': 'str',
        'rancher_api_key': 'str',
        'rancher_cluster_id': 'str',
        'use_local_ca_jwt': 'bool'
    }

    attribute_map = {
        'am_token_expiration': 'am_token_expiration',
        'auth_method_access_id': 'auth_method_access_id',
        'auth_method_prv_key_pem': 'auth_method_prv_key_pem',
        'cluster_api_type': 'cluster_api_type',
        'disable_iss_validation': 'disable_iss_validation',
        'id': 'id',
        'k8s_ca_cert': 'k8s_ca_cert',
        'k8s_host': 'k8s_host',
        'k8s_issuer': 'k8s_issuer',
        'k8s_pub_keys_pem': 'k8s_pub_keys_pem',
        'k8s_token_reviewer_jwt': 'k8s_token_reviewer_jwt',
        'name': 'name',
        'protection_key': 'protection_key',
        'rancher_api_key': 'rancher_api_key',
        'rancher_cluster_id': 'rancher_cluster_id',
        'use_local_ca_jwt': 'use_local_ca_jwt'
    }

    def __init__(self, am_token_expiration=None, auth_method_access_id=None, auth_method_prv_key_pem=None, cluster_api_type=None, disable_iss_validation=None, id=None, k8s_ca_cert=None, k8s_host=None, k8s_issuer=None, k8s_pub_keys_pem=None, k8s_token_reviewer_jwt=None, name=None, protection_key=None, rancher_api_key=None, rancher_cluster_id=None, use_local_ca_jwt=None, local_vars_configuration=None):  # noqa: E501
        """GatewayGetK8SAuthConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._am_token_expiration = None
        self._auth_method_access_id = None
        self._auth_method_prv_key_pem = None
        self._cluster_api_type = None
        self._disable_iss_validation = None
        self._id = None
        self._k8s_ca_cert = None
        self._k8s_host = None
        self._k8s_issuer = None
        self._k8s_pub_keys_pem = None
        self._k8s_token_reviewer_jwt = None
        self._name = None
        self._protection_key = None
        self._rancher_api_key = None
        self._rancher_cluster_id = None
        self._use_local_ca_jwt = None
        self.discriminator = None

        if am_token_expiration is not None:
            self.am_token_expiration = am_token_expiration
        if auth_method_access_id is not None:
            self.auth_method_access_id = auth_method_access_id
        if auth_method_prv_key_pem is not None:
            self.auth_method_prv_key_pem = auth_method_prv_key_pem
        if cluster_api_type is not None:
            self.cluster_api_type = cluster_api_type
        if disable_iss_validation is not None:
            self.disable_iss_validation = disable_iss_validation
        if id is not None:
            self.id = id
        if k8s_ca_cert is not None:
            self.k8s_ca_cert = k8s_ca_cert
        if k8s_host is not None:
            self.k8s_host = k8s_host
        if k8s_issuer is not None:
            self.k8s_issuer = k8s_issuer
        if k8s_pub_keys_pem is not None:
            self.k8s_pub_keys_pem = k8s_pub_keys_pem
        if k8s_token_reviewer_jwt is not None:
            self.k8s_token_reviewer_jwt = k8s_token_reviewer_jwt
        if name is not None:
            self.name = name
        if protection_key is not None:
            self.protection_key = protection_key
        if rancher_api_key is not None:
            self.rancher_api_key = rancher_api_key
        if rancher_cluster_id is not None:
            self.rancher_cluster_id = rancher_cluster_id
        if use_local_ca_jwt is not None:
            self.use_local_ca_jwt = use_local_ca_jwt

    @property
    def am_token_expiration(self):
        """Gets the am_token_expiration of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        AuthMethodTokenExpiration is time in seconds of expiration of the Akeyless Kube Auth Method token  # noqa: E501

        :return: The am_token_expiration of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._am_token_expiration

    @am_token_expiration.setter
    def am_token_expiration(self, am_token_expiration):
        """Sets the am_token_expiration of this GatewayGetK8SAuthConfigOutput.

        AuthMethodTokenExpiration is time in seconds of expiration of the Akeyless Kube Auth Method token  # noqa: E501

        :param am_token_expiration: The am_token_expiration of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: int
        """

        self._am_token_expiration = am_token_expiration

    @property
    def auth_method_access_id(self):
        """Gets the auth_method_access_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        AuthMethodAccessId of the Kubernetes auth method  # noqa: E501

        :return: The auth_method_access_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._auth_method_access_id

    @auth_method_access_id.setter
    def auth_method_access_id(self, auth_method_access_id):
        """Sets the auth_method_access_id of this GatewayGetK8SAuthConfigOutput.

        AuthMethodAccessId of the Kubernetes auth method  # noqa: E501

        :param auth_method_access_id: The auth_method_access_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._auth_method_access_id = auth_method_access_id

    @property
    def auth_method_prv_key_pem(self):
        """Gets the auth_method_prv_key_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        AuthMethodSigningKey is the private key (in base64 of the PEM format) associated with the public key defined in the Kubernetes auth method, that used to sign the internal token for the Akeyless Kubernetes Auth Method  # noqa: E501

        :return: The auth_method_prv_key_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._auth_method_prv_key_pem

    @auth_method_prv_key_pem.setter
    def auth_method_prv_key_pem(self, auth_method_prv_key_pem):
        """Sets the auth_method_prv_key_pem of this GatewayGetK8SAuthConfigOutput.

        AuthMethodSigningKey is the private key (in base64 of the PEM format) associated with the public key defined in the Kubernetes auth method, that used to sign the internal token for the Akeyless Kubernetes Auth Method  # noqa: E501

        :param auth_method_prv_key_pem: The auth_method_prv_key_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._auth_method_prv_key_pem = auth_method_prv_key_pem

    @property
    def cluster_api_type(self):
        """Gets the cluster_api_type of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        ClusterApiType defines types of API access to cluster  # noqa: E501

        :return: The cluster_api_type of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._cluster_api_type

    @cluster_api_type.setter
    def cluster_api_type(self, cluster_api_type):
        """Sets the cluster_api_type of this GatewayGetK8SAuthConfigOutput.

        ClusterApiType defines types of API access to cluster  # noqa: E501

        :param cluster_api_type: The cluster_api_type of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._cluster_api_type = cluster_api_type

    @property
    def disable_iss_validation(self):
        """Gets the disable_iss_validation of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        DisableISSValidation is optional parameter to disable ISS validation  # noqa: E501

        :return: The disable_iss_validation of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: bool
        """
        return self._disable_iss_validation

    @disable_iss_validation.setter
    def disable_iss_validation(self, disable_iss_validation):
        """Sets the disable_iss_validation of this GatewayGetK8SAuthConfigOutput.

        DisableISSValidation is optional parameter to disable ISS validation  # noqa: E501

        :param disable_iss_validation: The disable_iss_validation of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: bool
        """

        self._disable_iss_validation = disable_iss_validation

    @property
    def id(self):
        """Gets the id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501


        :return: The id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GatewayGetK8SAuthConfigOutput.


        :param id: The id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def k8s_ca_cert(self):
        """Gets the k8s_ca_cert of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        K8SCACert is the CA Cert to use to call into the kubernetes API  # noqa: E501

        :return: The k8s_ca_cert of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._k8s_ca_cert

    @k8s_ca_cert.setter
    def k8s_ca_cert(self, k8s_ca_cert):
        """Sets the k8s_ca_cert of this GatewayGetK8SAuthConfigOutput.

        K8SCACert is the CA Cert to use to call into the kubernetes API  # noqa: E501

        :param k8s_ca_cert: The k8s_ca_cert of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._k8s_ca_cert = k8s_ca_cert

    @property
    def k8s_host(self):
        """Gets the k8s_host of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        K8SHost is the url string for the kubernetes API  # noqa: E501

        :return: The k8s_host of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._k8s_host

    @k8s_host.setter
    def k8s_host(self, k8s_host):
        """Sets the k8s_host of this GatewayGetK8SAuthConfigOutput.

        K8SHost is the url string for the kubernetes API  # noqa: E501

        :param k8s_host: The k8s_host of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._k8s_host = k8s_host

    @property
    def k8s_issuer(self):
        """Gets the k8s_issuer of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        K8SIssuer is the claim that specifies who issued the Kubernetes token  # noqa: E501

        :return: The k8s_issuer of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._k8s_issuer

    @k8s_issuer.setter
    def k8s_issuer(self, k8s_issuer):
        """Sets the k8s_issuer of this GatewayGetK8SAuthConfigOutput.

        K8SIssuer is the claim that specifies who issued the Kubernetes token  # noqa: E501

        :param k8s_issuer: The k8s_issuer of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._k8s_issuer = k8s_issuer

    @property
    def k8s_pub_keys_pem(self):
        """Gets the k8s_pub_keys_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        K8SPublicKeysPEM is the list of public key in PEM format  # noqa: E501

        :return: The k8s_pub_keys_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._k8s_pub_keys_pem

    @k8s_pub_keys_pem.setter
    def k8s_pub_keys_pem(self, k8s_pub_keys_pem):
        """Sets the k8s_pub_keys_pem of this GatewayGetK8SAuthConfigOutput.

        K8SPublicKeysPEM is the list of public key in PEM format  # noqa: E501

        :param k8s_pub_keys_pem: The k8s_pub_keys_pem of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: list[str]
        """

        self._k8s_pub_keys_pem = k8s_pub_keys_pem

    @property
    def k8s_token_reviewer_jwt(self):
        """Gets the k8s_token_reviewer_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        K8STokenReviewerJWT is the bearer for clusterApiTypeK8s, used during TokenReview API call  # noqa: E501

        :return: The k8s_token_reviewer_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._k8s_token_reviewer_jwt

    @k8s_token_reviewer_jwt.setter
    def k8s_token_reviewer_jwt(self, k8s_token_reviewer_jwt):
        """Sets the k8s_token_reviewer_jwt of this GatewayGetK8SAuthConfigOutput.

        K8STokenReviewerJWT is the bearer for clusterApiTypeK8s, used during TokenReview API call  # noqa: E501

        :param k8s_token_reviewer_jwt: The k8s_token_reviewer_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._k8s_token_reviewer_jwt = k8s_token_reviewer_jwt

    @property
    def name(self):
        """Gets the name of this GatewayGetK8SAuthConfigOutput.  # noqa: E501


        :return: The name of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayGetK8SAuthConfigOutput.


        :param name: The name of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def protection_key(self):
        """Gets the protection_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501


        :return: The protection_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this GatewayGetK8SAuthConfigOutput.


        :param protection_key: The protection_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def rancher_api_key(self):
        """Gets the rancher_api_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        RancherApiKey the bear token for clusterApiTypeRancher  # noqa: E501

        :return: The rancher_api_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._rancher_api_key

    @rancher_api_key.setter
    def rancher_api_key(self, rancher_api_key):
        """Sets the rancher_api_key of this GatewayGetK8SAuthConfigOutput.

        RancherApiKey the bear token for clusterApiTypeRancher  # noqa: E501

        :param rancher_api_key: The rancher_api_key of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._rancher_api_key = rancher_api_key

    @property
    def rancher_cluster_id(self):
        """Gets the rancher_cluster_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        RancherClusterId cluster id as define in rancher (in case of clusterApiTypeRancher)  # noqa: E501

        :return: The rancher_cluster_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._rancher_cluster_id

    @rancher_cluster_id.setter
    def rancher_cluster_id(self, rancher_cluster_id):
        """Sets the rancher_cluster_id of this GatewayGetK8SAuthConfigOutput.

        RancherClusterId cluster id as define in rancher (in case of clusterApiTypeRancher)  # noqa: E501

        :param rancher_cluster_id: The rancher_cluster_id of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: str
        """

        self._rancher_cluster_id = rancher_cluster_id

    @property
    def use_local_ca_jwt(self):
        """Gets the use_local_ca_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501

        UseLocalCAJwt is an optional parameter to set defaulting to using the local CA cert and service account jwt when running in a Kubernetes pod  # noqa: E501

        :return: The use_local_ca_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :rtype: bool
        """
        return self._use_local_ca_jwt

    @use_local_ca_jwt.setter
    def use_local_ca_jwt(self, use_local_ca_jwt):
        """Sets the use_local_ca_jwt of this GatewayGetK8SAuthConfigOutput.

        UseLocalCAJwt is an optional parameter to set defaulting to using the local CA cert and service account jwt when running in a Kubernetes pod  # noqa: E501

        :param use_local_ca_jwt: The use_local_ca_jwt of this GatewayGetK8SAuthConfigOutput.  # noqa: E501
        :type: bool
        """

        self._use_local_ca_jwt = use_local_ca_jwt

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayGetK8SAuthConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayGetK8SAuthConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.migrations_config_part import MigrationsConfigPart  # noqa: E501
from akeyless.rest import ApiException

class TestMigrationsConfigPart(unittest.TestCase):
    """MigrationsConfigPart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MigrationsConfigPart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.migrations_config_part.MigrationsConfigPart()  # noqa: E501
        if include_optional :
            return MigrationsConfigPart(
                aws_secrets_migrations = [
                    akeyless.models.aws_secrets_migration.AWSSecretsMigration(
                        general = akeyless.models.migration_general.MigrationGeneral(
                            id = '0', 
                            name = '0', 
                            prefix = '0', 
                            protection_key = '0', ), 
                        payload = akeyless.models.aws_payload.AWSPayload(
                            key = '0', 
                            region = '0', 
                            secret = '0', ), )
                    ], 
                azure_kv_migrations = [
                    akeyless.models.azure_key_vault_migration.AzureKeyVaultMigration(
                        general = akeyless.models.migration_general.MigrationGeneral(
                            id = '0', 
                            name = '0', 
                            prefix = '0', 
                            protection_key = '0', ), 
                        payload = akeyless.models.azure_payload.AzurePayload(
                            client = '0', 
                            name = '0', 
                            secret = '0', 
                            tenant = '0', ), )
                    ], 
                hashi_migrations = [
                    akeyless.models.hashi_migration.HashiMigration(
                        general = akeyless.models.migration_general.MigrationGeneral(
                            id = '0', 
                            name = '0', 
                            prefix = '0', 
                            protection_key = '0', ), 
                        payload = akeyless.models.hashi_payload.HashiPayload(
                            namespaces = [
                                '0'
                                ], 
                            token = '0', 
                            url = '0', ), )
                    ], 
                k8s_migrations = [
                    akeyless.models.k8_s_migration.K8SMigration(
                        general = akeyless.models.migration_general.MigrationGeneral(
                            id = '0', 
                            name = '0', 
                            prefix = '0', 
                            protection_key = '0', ), 
                        payload = akeyless.models.k8_s_payload.K8SPayload(
                            ca = [
                                56
                                ], 
                            client_cert = [
                                56
                                ], 
                            client_key = [
                                56
                                ], 
                            namespace = '0', 
                            password = '0', 
                            server = '0', 
                            skip_system = True, 
                            token = '0', 
                            username = '0', ), )
                    ]
            )
        else :
            return MigrationsConfigPart(
        )

    def testMigrationsConfigPart(self):
        """Test MigrationsConfigPart"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
